@@ -1,5 +1,6 @@
 from common import TestMetaWearBase, to_string_buffer
-from mbientlab.metawear.cbindings import *
+from cbindings import *
+#from mbientlab.metawear.cbindings import *
 from threading import Event
 
 class AnonymousSignalBase(TestMetaWearBase):
@@ -438,4 +439,4 @@ class TestFuser(AnonymousSignalBase):
         self.notify_mw_char(to_string_buffer([0x0b, 0x07, 0xc2, 0xac, 0x1b, 0x00, 0x00, 0x79, 0x00, 0x0c, 0x00, 0xc0, 0xc8, 0x1b, 0x00, 0x00, 0x36, 0xff, 0x35, 0x01]))
         self.notify_mw_char(to_string_buffer([0x0b, 0x07, 0xc1, 0xc8, 0x1b, 0x00, 0x00, 0x02, 0x42, 0x50, 0x00, 0xc2, 0xc8, 0x1b, 0x00, 0x00, 0x82, 0x00, 0x1d, 0x00]))
 
-        self.assertEqual(results, expected)
\ No newline at end of file
+        self.assertEqual(results, expected)
